==> aliyun-python-sdk-imm-1.6.2.tar.gz: aliyun-python-sdk-imm-1.6.2/aliyunsdkimm/request/v20170906/RegistFaceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RegistFaceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'RegistFace','2017-09-06')

	def get_ChooseBiggestFace(self):
		return self.get_query_params().get('ChooseBiggestFace')

	def set_ChooseBiggestFace(self,ChooseBiggestFace):
		self.add_query_param('ChooseBiggestFace',ChooseBiggestFace)

	def get_IsQualityLimit(self):
		return self.get_query_params().get('IsQualityLimit')

	def set_IsQualityLimit(self,IsQualityLimit):
		self.add_query_param('IsQualityLimit',IsQualityLimit)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_SrcUri(self):
		return self.get_query_params().get('SrcUri')

	def set_SrcUri(self,SrcUri):
		self.add_query_param('SrcUri',SrcUri)

	def get_RegisterCheckLevel(self):
		return self.get_query_params().get('RegisterCheckLevel')

	def set_RegisterCheckLevel(self,RegisterCheckLevel):
		self.add_query_param('RegisterCheckLevel',RegisterCheckLevel)

	def get_GroupName(self):
		return self.get_query_params().get('GroupName')

	def set_GroupName(self,GroupName):
		self.add_query_param('GroupName',GroupName)

	def get_User(self):
		return self.get_query_params().get('User')

	def set_User(self,User):
		self.add_query_param('User',User)

==> aliyun-python-sdk-imm-1.9.4.tar.gz: aliyun-python-sdk-imm-1.9.4/aliyunsdkimm/request/v20170906/RegistFaceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RegistFaceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'RegistFace','imm')

	def get_ChooseBiggestFace(self):
		return self.get_query_params().get('ChooseBiggestFace')

	def set_ChooseBiggestFace(self,ChooseBiggestFace):
		self.add_query_param('ChooseBiggestFace',ChooseBiggestFace)

	def get_IsQualityLimit(self):
		return self.get_query_params().get('IsQualityLimit')

	def set_IsQualityLimit(self,IsQualityLimit):
		self.add_query_param('IsQualityLimit',IsQualityLimit)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_SrcUri(self):
		return self.get_query_params().get('SrcUri')

	def set_SrcUri(self,SrcUri):
		self.add_query_param('SrcUri',SrcUri)

	def get_RegisterCheckLevel(self):
		return self.get_query_params().get('RegisterCheckLevel')

	def set_RegisterCheckLevel(self,RegisterCheckLevel):
		self.add_query_param('RegisterCheckLevel',RegisterCheckLevel)

	def get_GroupName(self):
		return self.get_query_params().get('GroupName')

	def set_GroupName(self,GroupName):
		self.add_query_param('GroupName',GroupName)

	def get_User(self):
		return self.get_query_params().get('User')

	def set_User(self,User):
		self.add_query_param('User',User)
